Aux class
Some auxiliary functions to help.
Constructors
- Aux(InitParams params, RateLimiter limiter, Client _client)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limiter → RateLimiter
-
final
- params → InitParams
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
matchSongMusicBrainz(
{required String name, required List< String> artists, String? album, int? durationInSeconds}) → Future<Map< String, dynamic> ?> - Tries to associate a track info to a MusicBrainz recording
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited